# FeelUOwn-bilibili

FeelUOwn plugin for bilibili

## Installation

```sh
pip3 install fuo-bilibili
```

## Changelog

### 0.1.3 (2021-11-21)
- 基于 FeelUOwn 3.7.13 的接口，提供简单的弹幕渲染功能

### 0.1 (2021-11-06)
- 实现基本的视频相关接口，支持播放视频资源
  比如：`fuo play fuo://bilibili/videos/BV18s411W7by`
